@@ -14,23 +14,31 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
- * USA
+ * License along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef __PYGI_INVOKE_H__
 #define __PYGI_INVOKE_H__
 
-#include <Python.h>
+#include <girepository/girepository.h>
+#include <pythoncapi_compat.h>
 
-#include <girepository.h>
-
-#include "pygi-private.h"
+#include "pygi-info.h"
+#include "pygi-invoke-state-struct.h"
 
 G_BEGIN_DECLS
 
-PyObject *_wrap_g_function_info_invoke (PyGIBaseInfo *self, PyObject *py_args);
+PyObject *pygi_invoke_c_callable (PyGIFunctionCache *function_cache,
+                                  PyGIInvokeState *state,
+                                  PyObject *const *py_args, size_t py_nargsf,
+                                  PyObject *py_kwnames);
+PyObject *pygi_callable_info_invoke (PyGICallableInfo *self,
+                                     PyObject *const *py_args,
+                                     size_t py_nargsf, PyObject *kwnames);
+
+gboolean _pygi_invoke_arg_state_init (PyGIInvokeState *state);
+
+void _pygi_invoke_arg_state_free (PyGIInvokeState *state);
 
 G_END_DECLS
 
