@@ -32,15 +32,11 @@ typedef struct {
 
 extern PyTypeObject PyGIStruct_Type;
 
-PyObject *
-pygi_struct_new (PyTypeObject *type,
-                 gpointer      pointer,
-                 gboolean      free_on_dealloc);
+PyObject *pygi_struct_new (PyTypeObject *type, gpointer pointer,
+                           gboolean free_on_dealloc);
 
-PyObject *
-pygi_struct_new_from_g_type (GType g_type,
-                             gpointer      pointer,
-                             gboolean      free_on_dealloc);
+PyObject *pygi_struct_new_from_g_type (GType g_type, gpointer pointer,
+                                       gboolean free_on_dealloc);
 
 int pygi_struct_register_types (PyObject *m);
 
