@@ -15,12 +15,14 @@
 #  define PYTHON3 1
 #endif
 
-#if defined(_MSC_VER) && defined(__cplusplus)
-#  define MODULE_NAME test_pythoncapi_compat_cppext
+#if defined(__cplusplus) && __cplusplus >= 201402
+#  define MODULE_NAME test_pythoncapi_compat_cpp14ext
 #elif defined(__cplusplus) && __cplusplus >= 201103
 #  define MODULE_NAME test_pythoncapi_compat_cpp11ext
-#elif defined(__cplusplus)
+#elif defined(__cplusplus) && !defined(_MSC_VER)
 #  define MODULE_NAME test_pythoncapi_compat_cpp03ext
+#elif defined(__cplusplus)
+#  define MODULE_NAME test_pythoncapi_compat_cppext
 #else
 #  define MODULE_NAME test_pythoncapi_compat_cext
 #endif
@@ -756,7 +758,7 @@ test_import(PyObject *Py_UNUSED(module), PyObject *Py_UNUSED(args))
 static void
 gc_collect(void)
 {
-#if defined(PYPY_VERSION)
+#if defined(PYPY_VERSION) && PY_VERSION_HEX < 0x030B0000
     PyObject *mod = PyImport_ImportModule("gc");
     assert(mod != _Py_NULL);
 
@@ -1419,14 +1421,63 @@ test_long_api(PyObject *Py_UNUSED(module), PyObject *Py_UNUSED(args))
     assert(PyLong_GetSign(obj, &sign) == 0);
     assert(sign == 1);
 
+    // test PyLong_IsPositive(), PyLong_IsNegative() and PyLong_IsZero()
+    assert(PyLong_IsPositive(obj) == 1);
+    assert(PyLong_IsNegative(obj) == 0);
+    assert(PyLong_IsZero(obj) == 0);
+
+#if defined(PYTHON3) && !defined(PYPY_VERSION)
+    // test import/export API
+    digit *digits;
+    PyLongWriter *writer;
+    static PyLongExport long_export;
+
+    writer = PyLongWriter_Create(1, 1, (void**)&digits);
+    PyLongWriter_Discard(writer);
+
+    writer = PyLongWriter_Create(1, 1, (void**)&digits);
+    digits[0] = 123;
+    obj = PyLongWriter_Finish(writer);
+
+    check_int(obj, -123);
+    PyLong_Export(obj, &long_export);
+    assert(long_export.value == -123);
+    assert(long_export.digits == NULL);
+    PyLong_FreeExport(&long_export);
+    Py_DECREF(obj);
+
+    writer = PyLongWriter_Create(0, 5, (void**)&digits);
+    digits[0] = 1;
+    digits[1] = 0;
+    digits[2] = 0;
+    digits[3] = 0;
+    digits[4] = 1;
+    obj = PyLongWriter_Finish(writer);
+
+    PyLong_Export(obj, &long_export);
+    assert(long_export.value == 0);
+    digits = (digit*)long_export.digits;
+    assert(digits[0] == 1);
+    assert(digits[1] == 0);
+    assert(digits[2] == 0);
+    assert(digits[3] == 0);
+    assert(digits[4] == 1);
+    PyLong_FreeExport(&long_export);
+    Py_DECREF(obj);
+
+    const PyLongLayout *layout = PyLong_GetNativeLayout();
+    assert(layout->digits_order == -1);
+    assert(layout->digit_size == sizeof(digit));
+#endif // defined(PYTHON3) && !defined(PYPY_VERSION)
+
     Py_RETURN_NONE;
 }
 
 
 // --- HeapCTypeWithManagedDict --------------------------------------------
 
-// Py_TPFLAGS_MANAGED_DICT was added to Python 3.11.0a3
-#if PY_VERSION_HEX >= 0x030B00A3
+// Py_TPFLAGS_MANAGED_DICT was added to Python 3.11.0a3 but is not implemented on PyPy
+#if PY_VERSION_HEX >= 0x030B00A3 && ! defined(PYPY_VERSION)
 #  define TEST_MANAGED_DICT
 
 typedef struct {
@@ -1437,12 +1488,14 @@ static int
 heapmanaged_traverse(PyObject *self, visitproc visit, void *arg)
 {
     Py_VISIT(Py_TYPE(self));
+    // Test PyObject_VisitManagedDict()
     return PyObject_VisitManagedDict(self, visit, arg);
 }
 
 static int
 heapmanaged_clear(PyObject *self)
 {
+    // Test PyObject_ClearManagedDict()
     PyObject_ClearManagedDict(self);
     return 0;
 }
@@ -1475,6 +1528,7 @@ static PyType_Spec HeapCTypeWithManagedDict_spec = {
 static PyObject *
 test_managed_dict(PyObject *Py_UNUSED(module), PyObject *Py_UNUSED(args))
 {
+    // Test PyObject_VisitManagedDict() and PyObject_ClearManagedDict()
     PyObject *type = PyType_FromSpec(&HeapCTypeWithManagedDict_spec);
     if (type == NULL) {
         return NULL;
@@ -1531,6 +1585,13 @@ test_unicode(PyObject *Py_UNUSED(module), PyObject *Py_UNUSED(args))
     assert(PyErr_ExceptionMatches(PyExc_MemoryError));
     PyErr_Clear();
 
+    // Test PyUnicode_Equal()
+    assert(PyUnicode_Equal(abc, abc) == 1);
+    assert(PyUnicode_Equal(abc, abc0def) == 0);
+    assert(PyUnicode_Equal(abc, Py_True) == -1);
+    assert(PyErr_ExceptionMatches(PyExc_TypeError));
+    PyErr_Clear();
+
     Py_DECREF(abc);
     Py_DECREF(abc0def);
     Py_RETURN_NONE;
@@ -1599,7 +1660,7 @@ test_hash(PyObject *Py_UNUSED(module), PyObject *Py_UNUSED(args))
 
 #if ((!defined(PYPY_VERSION) && PY_VERSION_HEX >= 0x030400B1) \
      || (defined(PYPY_VERSION) && PY_VERSION_HEX >= 0x03070000 \
-         && PYPY_VERSION_NUM >= 0x07090000))
+         && PYPY_VERSION_NUM >= 0x07030800))
     // Just check that constants are available
     size_t bits = PyHASH_BITS;
     assert(bits >= 8);
@@ -1611,6 +1672,20 @@ test_hash(PyObject *Py_UNUSED(module), PyObject *Py_UNUSED(args))
     assert(imag != 0);
 #endif
 
+    // Test Py_HashBuffer()
+    {
+        PyObject *abc = PyBytes_FromString("abc");
+        if (abc == NULL) {
+            return NULL;
+        }
+        Py_hash_t hash = Py_HashBuffer(PyBytes_AS_STRING(abc),
+                                       PyBytes_GET_SIZE(abc));
+        Py_hash_t hash2 = PyObject_Hash(abc);
+        assert(hash == hash2);
+
+        Py_DECREF(abc);
+    }
+
     Py_RETURN_NONE;
 }
 
@@ -1662,7 +1737,7 @@ check_get_constant(PyObject* (*get_constant)(unsigned int), int borrowed)
 
     // Py_CONSTANT_FALSE
     obj = get_constant(Py_CONSTANT_FALSE);
-    assert(obj = Py_False);
+    assert(obj == Py_False);
     CLEAR(obj);
 
     // Py_CONSTANT_TRUE
@@ -1874,6 +1949,238 @@ error:
 #endif
 
 
+static PyObject *
+test_bytes(PyObject *Py_UNUSED(module), PyObject *Py_UNUSED(args))
+{
+    // Test PyBytes_Join()
+    PyObject *abc = PyBytes_FromString("a b c");
+    if (abc == NULL) {
+        return NULL;
+    }
+    PyObject *list = PyObject_CallMethod(abc, "split", NULL);
+    Py_DECREF(abc);
+    if (list == NULL) {
+        return NULL;
+    }
+    PyObject *sep = PyBytes_FromString("-");
+    if (sep == NULL) {
+        Py_DECREF(list);
+        return NULL;
+    }
+
+    PyObject *join = PyBytes_Join(sep, list);
+    assert(join != NULL);
+    assert(PyBytes_Check(join));
+    assert(memcmp(PyBytes_AS_STRING(join), "a-b-c", 5) == 0);
+    Py_DECREF(join);
+
+    Py_DECREF(list);
+    Py_DECREF(sep);
+    Py_RETURN_NONE;
+}
+
+
+static PyObject *
+test_iter(PyObject *Py_UNUSED(module), PyObject *Py_UNUSED(args))
+{
+    // Test PyIter_NextItem()
+    PyObject *tuple = Py_BuildValue("(i)", 123);
+    if (tuple == NULL) {
+        return NULL;
+    }
+    PyObject *iter = PyObject_GetIter(tuple);
+    Py_DECREF(tuple);
+    if (iter == NULL) {
+        return NULL;
+    }
+
+    // first item
+    PyObject *item = UNINITIALIZED_OBJ;
+    assert(PyIter_NextItem(iter, &item) == 1);
+    {
+        PyObject *expected = PyLong_FromLong(123);
+        assert(PyObject_RichCompareBool(item, expected, Py_EQ) == 1);
+        assert(expected != NULL);
+        Py_DECREF(expected);
+    }
+
+    // StopIteration
+    item = UNINITIALIZED_OBJ;
+    assert(PyIter_NextItem(iter, &item) == 0);
+    assert(item == NULL);
+    assert(!PyErr_Occurred());
+
+    // non-iterable object
+    item = UNINITIALIZED_OBJ;
+    assert(PyIter_NextItem(Py_None, &item) == -1);
+    assert(item == NULL);
+    assert(PyErr_ExceptionMatches(PyExc_TypeError));
+    PyErr_Clear();
+
+    Py_DECREF(iter);
+    Py_RETURN_NONE;
+}
+
+
+static PyObject *
+test_long_stdint(PyObject *Py_UNUSED(module), PyObject *Py_UNUSED(args))
+{
+    PyObject *obj;
+
+    // Test PyLong_FromInt32() and PyLong_AsInt32()
+    obj = PyLong_FromInt32(INT32_C(-0x12345678));
+    assert(obj != NULL);
+    int32_t i32;
+    assert(PyLong_AsInt32(obj, &i32) == 0);
+    assert(i32 == INT32_C(-0x12345678));
+    Py_DECREF(obj);
+
+    // Test PyLong_FromUInt32() and PyLong_AsUInt32()
+    obj = PyLong_FromUInt32(UINT32_C(0xDEADBEEF));
+    assert(obj != NULL);
+    uint32_t u32;
+    assert(PyLong_AsUInt32(obj, &u32) == 0);
+    assert(u32 == UINT32_C(0xDEADBEEF));
+    Py_DECREF(obj);
+
+    // Test PyLong_FromInt64() and PyLong_AsInt64()
+    obj = PyLong_FromInt64(INT64_C(-0x12345678DEADBEEF));
+    assert(obj != NULL);
+    int64_t i64;
+    assert(PyLong_AsInt64(obj, &i64) == 0);
+    assert(i64 == INT64_C(-0x12345678DEADBEEF));
+    Py_DECREF(obj);
+
+    // Test PyLong_FromUInt64() and PyLong_AsUInt64()
+    obj = PyLong_FromUInt64(UINT64_C(0xDEADBEEF12345678));
+    assert(obj != NULL);
+    uint64_t u64;
+    assert(PyLong_AsUInt64(obj, &u64) == 0);
+    assert(u64 == UINT64_C(0xDEADBEEF12345678));
+    Py_DECREF(obj);
+
+    Py_RETURN_NONE;
+}
+
+
+static PyObject *
+test_structmember(PyObject *Py_UNUSED(module), PyObject *Py_UNUSED(args))
+{
+    assert(Py_T_SHORT >= 0);
+    assert(Py_T_INT >= 0);
+    assert(Py_T_LONG >= 0);
+    assert(Py_T_FLOAT >= 0);
+    assert(Py_T_DOUBLE >= 0);
+    assert(Py_T_STRING >= 0);
+    assert(_Py_T_OBJECT >= 0);
+    assert(Py_T_CHAR >= 0);
+    assert(Py_T_BYTE >= 0);
+    assert(Py_T_UBYTE >= 0);
+    assert(Py_T_USHORT >= 0);
+    assert(Py_T_UINT >= 0);
+    assert(Py_T_ULONG >= 0);
+    assert(Py_T_STRING_INPLACE >= 0);
+    assert(Py_T_BOOL >= 0);
+    assert(Py_T_OBJECT_EX >= 0);
+    assert(Py_T_LONGLONG >= 0);
+    assert(Py_T_ULONGLONG >= 0);
+    assert(Py_T_PYSSIZET >= 0);
+#if PY_VERSION_HEX >= 0x03000000 && !defined(PYPY_VERSION)
+    assert(_Py_T_NONE >= 0);
+#endif
+
+    assert(Py_READONLY >= 0);
+    assert(Py_AUDIT_READ >= 0);
+    assert(_Py_WRITE_RESTRICTED >= 0);
+
+    Py_RETURN_NONE;
+}
+
+
+static PyObject *
+test_file(PyObject *Py_UNUSED(module), PyObject *Py_UNUSED(args))
+{
+    const char *filename = __FILE__;
+    PyObject *path = create_string(filename);
+
+    FILE *fp = Py_fopen(path, "rb");
+    Py_DECREF(path);
+    assert(fp != NULL);
+    Py_fclose(fp);
+
+    Py_RETURN_NONE;
+}
+
+
+#if 0x03090000 <= PY_VERSION_HEX && !defined(PYPY_VERSION)
+static PyObject *
+test_config(PyObject *Py_UNUSED(module), PyObject *Py_UNUSED(args))
+{
+    // Test PyConfig_Get()
+    PyObject *sys = PyImport_ImportModule("sys");
+    if (sys == _Py_NULL) {
+        return _Py_NULL;
+    }
+
+    PyObject *obj = PyConfig_Get("argv");
+    PyObject *sys_attr = PyObject_GetAttrString(sys, "argv");
+    assert(obj == sys_attr);
+    Py_DECREF(obj);
+    Py_DECREF(sys_attr);
+
+    obj = PyConfig_Get("module_search_paths");
+    sys_attr = PyObject_GetAttrString(sys, "path");
+    assert(obj == sys_attr);
+    Py_DECREF(obj);
+    Py_DECREF(sys_attr);
+
+    obj = PyConfig_Get("xoptions");
+    sys_attr = PyObject_GetAttrString(sys, "_xoptions");
+    assert(obj == sys_attr);
+    Py_DECREF(obj);
+    Py_DECREF(sys_attr);
+
+    obj = PyConfig_Get("use_environment");
+    assert(PyBool_Check(obj));
+    Py_DECREF(obj);
+
+    obj = PyConfig_Get("verbose");
+    assert(PyLong_Check(obj));
+    Py_DECREF(obj);
+
+    // Get the last member
+#if 0x030A0000 <= PY_VERSION_HEX
+    obj = PyConfig_Get("warn_default_encoding");
+#else
+    obj = PyConfig_Get("user_site_directory");
+#endif
+    assert(PyLong_Check(obj));
+    Py_DECREF(obj);
+
+    assert(PyConfig_Get("nonexistent") == NULL);
+    assert(PyErr_ExceptionMatches(PyExc_ValueError));
+    PyErr_Clear();
+
+    // Test PyConfig_GetInt()
+    int value = -3;
+
+    assert(PyConfig_GetInt("verbose", &value) == 0);
+    assert(value >= 0);
+
+    assert(PyConfig_GetInt("argv", &value) == -1);
+    assert(PyErr_ExceptionMatches(PyExc_TypeError));
+    PyErr_Clear();
+
+    assert(PyConfig_GetInt("nonexistent", &value) == -1);
+    assert(PyErr_ExceptionMatches(PyExc_ValueError));
+    PyErr_Clear();
+
+    Py_DECREF(sys);
+    Py_RETURN_NONE;
+}
+#endif
+
+
 static struct PyMethodDef methods[] = {
     {"test_object", test_object, METH_NOARGS, _Py_NULL},
     {"test_py_is", test_py_is, METH_NOARGS, _Py_NULL},
@@ -1916,6 +2223,14 @@ static struct PyMethodDef methods[] = {
     {"test_unicodewriter", test_unicodewriter, METH_NOARGS, _Py_NULL},
     {"test_unicodewriter_widechar", test_unicodewriter_widechar, METH_NOARGS, _Py_NULL},
     {"test_unicodewriter_format", test_unicodewriter_format, METH_NOARGS, _Py_NULL},
+#endif
+    {"test_bytes", test_bytes, METH_NOARGS, _Py_NULL},
+    {"test_iter", test_iter, METH_NOARGS, _Py_NULL},
+    {"test_long_stdint", test_long_stdint, METH_NOARGS, _Py_NULL},
+    {"test_structmember", test_structmember, METH_NOARGS, _Py_NULL},
+    {"test_file", test_file, METH_NOARGS, _Py_NULL},
+#if 0x03090000 <= PY_VERSION_HEX && !defined(PYPY_VERSION)
+    {"test_config", test_config, METH_NOARGS, _Py_NULL},
 #endif
     {_Py_NULL, _Py_NULL, 0, _Py_NULL}
 };
