@@ -1,12 +1,10 @@
-# -*- Mode: Python; py-indent-offset: 4 -*-
-# vim: tabstop=4 shiftwidth=4 expandtab
-
 import unittest
 import weakref
 import gc
 import sys
 import warnings
 
+from gi import PyGIDeprecationWarning
 from gi.repository import GObject
 from gi.repository import GIMarshallingTests
 import testhelper
@@ -17,7 +15,7 @@ except ImportError:
     Regress = None
 
 
-class StrongRef(object):
+class StrongRef:
     # A class that behaves like weakref.ref but holds a strong reference.
     # This allows re-use of the VFuncsBase by swapping out the ObjectRef
     # class var with either weakref.ref or StrongRef.
@@ -42,7 +40,7 @@ class VFuncsBase(GIMarshallingTests.Object):
     ObjectRef = weakref.ref
 
     def __init__(self):
-        super(VFuncsBase, self).__init__()
+        super().__init__()
 
         #: Hold ref of input or output python wrappers
         self.object_ref = None
@@ -110,7 +108,9 @@ class TestVFuncsWithObjectArg(unittest.TestCase):
 
         gc.collect()
         if hasattr(sys, "getrefcount"):
-            self.assertEqual(sys.getrefcount(vfuncs), 2)
+            self.assertEqual(
+                sys.getrefcount(vfuncs), 2 if sys.version_info < (3, 14) else 1
+            )
         self.assertEqual(vfuncs.__grefcount__, 1)
 
         del vfuncs
@@ -125,8 +125,10 @@ class TestVFuncsWithObjectArg(unittest.TestCase):
         # but pygobject tries to react to this in a reasonable way.
         vfuncs = self.VFuncs()
         with warnings.catch_warnings(record=True) as warn:
-            warnings.simplefilter('always')
-            ref_count, is_floating = vfuncs.get_ref_info_for_vfunc_out_object_transfer_none()
+            warnings.simplefilter("always")
+            ref_count, is_floating = (
+                vfuncs.get_ref_info_for_vfunc_out_object_transfer_none()
+            )
             if hasattr(sys, "getrefcount"):
                 self.assertTrue(issubclass(warn[0].category, RuntimeWarning))
 
@@ -143,8 +145,10 @@ class TestVFuncsWithObjectArg(unittest.TestCase):
         # Same as above except uses out arg instead of return
         vfuncs = self.VFuncs()
         with warnings.catch_warnings(record=True) as warn:
-            warnings.simplefilter('always')
-            ref_count, is_floating = vfuncs.get_ref_info_for_vfunc_out_object_transfer_none()
+            warnings.simplefilter("always")
+            ref_count, is_floating = (
+                vfuncs.get_ref_info_for_vfunc_out_object_transfer_none()
+            )
             if hasattr(sys, "getrefcount"):
                 self.assertTrue(issubclass(warn[0].category, RuntimeWarning))
 
@@ -157,7 +161,9 @@ class TestVFuncsWithObjectArg(unittest.TestCase):
 
     def test_vfunc_return_object_transfer_full(self):
         vfuncs = self.VFuncs()
-        ref_count, is_floating = vfuncs.get_ref_info_for_vfunc_return_object_transfer_full()
+        ref_count, is_floating = (
+            vfuncs.get_ref_info_for_vfunc_return_object_transfer_full()
+        )
 
         # The vfunc caller receives full ownership of a single ref which should not
         # be floating.
@@ -171,7 +177,9 @@ class TestVFuncsWithObjectArg(unittest.TestCase):
     def test_vfunc_out_object_transfer_full(self):
         # Same as above except uses out arg instead of return
         vfuncs = self.VFuncs()
-        ref_count, is_floating = vfuncs.get_ref_info_for_vfunc_out_object_transfer_full()
+        ref_count, is_floating = (
+            vfuncs.get_ref_info_for_vfunc_out_object_transfer_full()
+        )
 
         if hasattr(sys, "getrefcount"):
             self.assertEqual(ref_count, 1)
@@ -182,7 +190,9 @@ class TestVFuncsWithObjectArg(unittest.TestCase):
 
     def test_vfunc_in_object_transfer_none(self):
         vfuncs = self.VFuncs()
-        ref_count, is_floating = vfuncs.get_ref_info_for_vfunc_in_object_transfer_none(self.VFuncs.Object)
+        ref_count, is_floating = vfuncs.get_ref_info_for_vfunc_in_object_transfer_none(
+            self.VFuncs.Object
+        )
 
         gc.collect()
         self.assertEqual(vfuncs.in_object_grefcount, 2)  # initial + python wrapper
@@ -198,7 +208,9 @@ class TestVFuncsWithObjectArg(unittest.TestCase):
 
     def test_vfunc_in_object_transfer_full(self):
         vfuncs = self.VFuncs()
-        ref_count, is_floating = vfuncs.get_ref_info_for_vfunc_in_object_transfer_full(self.VFuncs.Object)
+        ref_count, is_floating = vfuncs.get_ref_info_for_vfunc_in_object_transfer_full(
+            self.VFuncs.Object
+        )
 
         gc.collect()
 
@@ -228,7 +240,9 @@ class TestVFuncsWithFloatingArg(unittest.TestCase):
     def test_vfunc_return_object_transfer_none_with_floating(self):
         # Python is expected to return a single floating reference without warning.
         vfuncs = self.VFuncs()
-        ref_count, is_floating = vfuncs.get_ref_info_for_vfunc_return_object_transfer_none()
+        ref_count, is_floating = (
+            vfuncs.get_ref_info_for_vfunc_return_object_transfer_none()
+        )
 
         # The ref count of the GObject returned to the caller (get_ref_info_for_vfunc_return_object_transfer_none)
         # should be a single floating ref
@@ -242,7 +256,9 @@ class TestVFuncsWithFloatingArg(unittest.TestCase):
     def test_vfunc_out_object_transfer_none_with_floating(self):
         # Same as above except uses out arg instead of return
         vfuncs = self.VFuncs()
-        ref_count, is_floating = vfuncs.get_ref_info_for_vfunc_out_object_transfer_none()
+        ref_count, is_floating = (
+            vfuncs.get_ref_info_for_vfunc_out_object_transfer_none()
+        )
 
         self.assertEqual(ref_count, 1)
         self.assertTrue(is_floating)
@@ -252,7 +268,9 @@ class TestVFuncsWithFloatingArg(unittest.TestCase):
 
     def test_vfunc_return_object_transfer_full_with_floating(self):
         vfuncs = self.VFuncs()
-        ref_count, is_floating = vfuncs.get_ref_info_for_vfunc_return_object_transfer_full()
+        ref_count, is_floating = (
+            vfuncs.get_ref_info_for_vfunc_return_object_transfer_full()
+        )
 
         # The vfunc caller receives full ownership of a single ref.
         if hasattr(sys, "getrefcount"):
@@ -265,7 +283,9 @@ class TestVFuncsWithFloatingArg(unittest.TestCase):
     def test_vfunc_out_object_transfer_full_with_floating(self):
         # Same as above except uses out arg instead of return
         vfuncs = self.VFuncs()
-        ref_count, is_floating = vfuncs.get_ref_info_for_vfunc_out_object_transfer_full()
+        ref_count, is_floating = (
+            vfuncs.get_ref_info_for_vfunc_out_object_transfer_full()
+        )
 
         if hasattr(sys, "getrefcount"):
             self.assertEqual(ref_count, 1)
@@ -288,7 +308,9 @@ class TestVFuncsWithFloatingArg(unittest.TestCase):
 
         vfuncs.ObjectRef = ref
 
-        ref_count, is_floating = vfuncs.get_ref_info_for_vfunc_in_object_transfer_none(self.VFuncs.Object)
+        ref_count, is_floating = vfuncs.get_ref_info_for_vfunc_in_object_transfer_none(
+            self.VFuncs.Object
+        )
 
         gc.collect()
 
@@ -307,8 +329,10 @@ class TestVFuncsWithFloatingArg(unittest.TestCase):
         self.assertEqual(vfuncs.object_ref().__grefcount__, 2)
         self.assertTrue(vfuncs.object_ref().is_floating())
         # Sinking and unref'ing our "C" one will drop both (as the second is a toggle ref)
-        vfuncs.object_ref()._ref_sink()
-        testhelper.force_g_object_unref(vfuncs.object_ref())
+        with warnings.catch_warnings():
+            warnings.simplefilter("ignore", PyGIDeprecationWarning)
+            vfuncs.object_ref()._ref_sink()
+            testhelper.force_g_object_unref(vfuncs.object_ref())
 
         gc.collect()
         gc.collect()
@@ -316,7 +340,9 @@ class TestVFuncsWithFloatingArg(unittest.TestCase):
 
     def test_vfunc_in_object_transfer_full_with_floating(self):
         vfuncs = self.VFuncs()
-        ref_count, is_floating = vfuncs.get_ref_info_for_vfunc_in_object_transfer_full(self.VFuncs.Object)
+        ref_count, is_floating = vfuncs.get_ref_info_for_vfunc_in_object_transfer_full(
+            self.VFuncs.Object
+        )
 
         gc.collect()
 
@@ -345,7 +371,9 @@ class TestVFuncsWithHeldObjectArg(unittest.TestCase):
 
     def test_vfunc_return_object_transfer_none_with_held_object(self):
         vfuncs = self.VFuncs()
-        ref_count, is_floating = vfuncs.get_ref_info_for_vfunc_return_object_transfer_none()
+        ref_count, is_floating = (
+            vfuncs.get_ref_info_for_vfunc_return_object_transfer_none()
+        )
 
         # Python holds the single gobject ref in 'vfuncs.object_ref'
         # Because of this, we do not expect a floating ref or a ref increase.
@@ -363,7 +391,9 @@ class TestVFuncsWithHeldObjectArg(unittest.TestCase):
 
     def test_vfunc_out_object_transfer_none_with_held_object(self):
         vfuncs = self.VFuncs()
-        ref_count, is_floating = vfuncs.get_ref_info_for_vfunc_out_object_transfer_none()
+        ref_count, is_floating = (
+            vfuncs.get_ref_info_for_vfunc_out_object_transfer_none()
+        )
 
         self.assertEqual(ref_count, 1)
         self.assertFalse(is_floating)
@@ -381,7 +411,9 @@ class TestVFuncsWithHeldObjectArg(unittest.TestCase):
         # be floating. However, the held python wrapper also has a ref.
 
         vfuncs = self.VFuncs()
-        ref_count, is_floating = vfuncs.get_ref_info_for_vfunc_return_object_transfer_full()
+        ref_count, is_floating = (
+            vfuncs.get_ref_info_for_vfunc_return_object_transfer_full()
+        )
 
         # Ref count from the perspective of C after the vfunc is called
         # The vfunc caller receives a new reference which should not
@@ -401,7 +433,9 @@ class TestVFuncsWithHeldObjectArg(unittest.TestCase):
     def test_vfunc_out_object_transfer_full_with_held_object(self):
         # Same test as above except uses out arg instead of return
         vfuncs = self.VFuncs()
-        ref_count, is_floating = vfuncs.get_ref_info_for_vfunc_out_object_transfer_full()
+        ref_count, is_floating = (
+            vfuncs.get_ref_info_for_vfunc_out_object_transfer_full()
+        )
 
         # Ref count from the perspective of C after the vfunc is called
         # The vfunc caller receives a new reference which should not
@@ -420,7 +454,9 @@ class TestVFuncsWithHeldObjectArg(unittest.TestCase):
 
     def test_vfunc_in_object_transfer_none_with_held_object(self):
         vfuncs = self.VFuncs()
-        ref_count, is_floating = vfuncs.get_ref_info_for_vfunc_in_object_transfer_none(self.VFuncs.Object)
+        ref_count, is_floating = vfuncs.get_ref_info_for_vfunc_in_object_transfer_none(
+            self.VFuncs.Object
+        )
 
         gc.collect()
 
@@ -442,12 +478,16 @@ class TestVFuncsWithHeldObjectArg(unittest.TestCase):
 
     def test_vfunc_in_object_transfer_full_with_held_object(self):
         vfuncs = self.VFuncs()
-        ref_count, is_floating = vfuncs.get_ref_info_for_vfunc_in_object_transfer_full(self.VFuncs.Object)
+        ref_count, is_floating = vfuncs.get_ref_info_for_vfunc_in_object_transfer_full(
+            self.VFuncs.Object
+        )
 
         gc.collect()
 
         # Ref count inside vfunc from the perspective of Python
-        self.assertEqual(vfuncs.in_object_grefcount, 1)  # python wrapper takes ownership of the gobject
+        self.assertEqual(
+            vfuncs.in_object_grefcount, 1
+        )  # python wrapper takes ownership of the gobject
         self.assertFalse(vfuncs.in_object_is_floating)
 
         # Ref count from the perspective of C after the vfunc is called
@@ -477,7 +517,9 @@ class TestVFuncsWithHeldFloatingArg(unittest.TestCase):
         # should also be owned by python.
 
         vfuncs = self.VFuncs()
-        ref_count, is_floating = vfuncs.get_ref_info_for_vfunc_return_object_transfer_none()
+        ref_count, is_floating = (
+            vfuncs.get_ref_info_for_vfunc_return_object_transfer_none()
+        )
 
         # This is a borrowed ref from what is held in python.
         self.assertEqual(ref_count, 1)
@@ -495,7 +537,9 @@ class TestVFuncsWithHeldFloatingArg(unittest.TestCase):
         # Same as above
 
         vfuncs = self.VFuncs()
-        ref_count, is_floating = vfuncs.get_ref_info_for_vfunc_out_object_transfer_none()
+        ref_count, is_floating = (
+            vfuncs.get_ref_info_for_vfunc_out_object_transfer_none()
+        )
 
         self.assertEqual(ref_count, 1)
         self.assertFalse(is_floating)
@@ -509,7 +553,9 @@ class TestVFuncsWithHeldFloatingArg(unittest.TestCase):
 
     def test_vfunc_return_object_transfer_full_with_held_floating(self):
         vfuncs = self.VFuncs()
-        ref_count, is_floating = vfuncs.get_ref_info_for_vfunc_return_object_transfer_full()
+        ref_count, is_floating = (
+            vfuncs.get_ref_info_for_vfunc_return_object_transfer_full()
+        )
 
         # Ref count from the perspective of C after the vfunc is called
         self.assertEqual(ref_count, 2)
@@ -527,7 +573,9 @@ class TestVFuncsWithHeldFloatingArg(unittest.TestCase):
     def test_vfunc_out_object_transfer_full_with_held_floating(self):
         # Same test as above except uses out arg instead of return
         vfuncs = self.VFuncs()
-        ref_count, is_floating = vfuncs.get_ref_info_for_vfunc_out_object_transfer_full()
+        ref_count, is_floating = (
+            vfuncs.get_ref_info_for_vfunc_out_object_transfer_full()
+        )
 
         # Ref count from the perspective of C after the vfunc is called
         self.assertEqual(ref_count, 2)
@@ -544,12 +592,16 @@ class TestVFuncsWithHeldFloatingArg(unittest.TestCase):
 
     def test_vfunc_in_floating_transfer_none_with_held_floating(self):
         vfuncs = self.VFuncs()
-        ref_count, is_floating = vfuncs.get_ref_info_for_vfunc_in_object_transfer_none(self.VFuncs.Object)
+        ref_count, is_floating = vfuncs.get_ref_info_for_vfunc_in_object_transfer_none(
+            self.VFuncs.Object
+        )
         gc.collect()
 
         # Ref count inside vfunc from the perspective of Python
         self.assertTrue(vfuncs.in_object_is_floating)
-        self.assertEqual(vfuncs.in_object_grefcount, 2)  # python wrapper sinks and owns the gobject
+        self.assertEqual(
+            vfuncs.in_object_grefcount, 2
+        )  # python wrapper sinks and owns the gobject
 
         # Ref count from the perspective of C after the vfunc is called
         self.assertTrue(is_floating)
@@ -562,7 +614,9 @@ class TestVFuncsWithHeldFloatingArg(unittest.TestCase):
         self.assertTrue(vfuncs.object_ref().is_floating())
         # ... usually it should have been sunk within C at some point,
         # do it here to avoid a critical warning.
-        vfuncs.object_ref()._ref_sink()
+        with warnings.catch_warnings():
+            warnings.simplefilter("ignore", PyGIDeprecationWarning)
+            vfuncs.object_ref()._ref_sink()
         # However, that means that the above comment of "sinks and owns" is wrong.
 
         held_object_ref = weakref.ref(vfuncs.object_ref())
@@ -572,11 +626,15 @@ class TestVFuncsWithHeldFloatingArg(unittest.TestCase):
 
     def test_vfunc_in_floating_transfer_full_with_held_floating(self):
         vfuncs = self.VFuncs()
-        ref_count, is_floating = vfuncs.get_ref_info_for_vfunc_in_object_transfer_full(self.VFuncs.Object)
+        ref_count, is_floating = vfuncs.get_ref_info_for_vfunc_in_object_transfer_full(
+            self.VFuncs.Object
+        )
         gc.collect()
 
         # Ref count from the perspective of C after the vfunc is called
-        self.assertEqual(vfuncs.in_object_grefcount, 1)  # python wrapper sinks and owns the gobject
+        self.assertEqual(
+            vfuncs.in_object_grefcount, 1
+        )  # python wrapper sinks and owns the gobject
         self.assertFalse(vfuncs.in_object_is_floating)
 
         # Ref count from the perspective of C after the vfunc is called
@@ -592,7 +650,7 @@ class TestVFuncsWithHeldFloatingArg(unittest.TestCase):
         self.assertTrue(held_object_ref() is None)
 
 
-@unittest.skipIf(Regress is None, 'Regress is required')
+@unittest.skipIf(Regress is None, "Regress is required")
 class TestArgumentTypeErrors(unittest.TestCase):
     def test_object_argument_type_error(self):
         # ensure TypeError is raised for things which are not GObjects
@@ -602,7 +660,7 @@ class TestArgumentTypeErrors(unittest.TestCase):
 
         self.assertRaises(TypeError, obj.set_bare, object())
         self.assertRaises(TypeError, obj.set_bare, 42)
-        self.assertRaises(TypeError, obj.set_bare, 'not an object')
+        self.assertRaises(TypeError, obj.set_bare, "not an object")
 
     def test_instance_argument_error(self):
         # ensure TypeError is raised for non Regress.TestObj instances.
@@ -611,12 +669,16 @@ class TestArgumentTypeErrors(unittest.TestCase):
         self.assertRaises(TypeError, Regress.TestObj.instance_method, object())
         self.assertRaises(TypeError, Regress.TestObj.instance_method, GObject.Object())
         self.assertRaises(TypeError, Regress.TestObj.instance_method, 42)
-        self.assertRaises(TypeError, Regress.TestObj.instance_method, 'not an object')
+        self.assertRaises(TypeError, Regress.TestObj.instance_method, "not an object")
 
     def test_instance_argument_base_type_error(self):
         # ensure TypeError is raised when a base type is passed to something
         # expecting a derived type
         obj = Regress.TestSubObj()
         self.assertEqual(Regress.TestSubObj.instance_method(obj), 0)
-        self.assertRaises(TypeError, Regress.TestSubObj.instance_method, GObject.Object())
-        self.assertRaises(TypeError, Regress.TestSubObj.instance_method, Regress.TestObj())
+        self.assertRaises(
+            TypeError, Regress.TestSubObj.instance_method, GObject.Object()
+        )
+        self.assertRaises(
+            TypeError, Regress.TestSubObj.instance_method, Regress.TestObj()
+        )
